<template>
  <div class="item_panel_box">
    <el-input size="mini" placeholder="输入关键字进行过滤" v-model="filterText">
    </el-input>
    <div class="box_item">
      <item-panel class="item-panel" v-loading="loading">
        <template v-for="(item, index) in filterNode">
          <item
            :key="index"
            :type="item.type || 'node'"
            :size="item.size || '80*48'"
            :shape="item.shape || 'flow-rect'"
            :model="{
              // must have model property
              color: item.color || '#1890FF',
              label: item.id || '节点'
            }"
          >
            <template v-if="item.src">
              <div class="item item-img">
                <img :src="item.src" :alt="item.id" />
              </div>
            </template>
            <template v-else>
              <div :class="'item item-' + (item.shape || 'flow-rect')">
                <span>{{ item.id }}</span>
              </div>
            </template>
          </item>
        </template>
      </item-panel>
    </div>
  </div>
</template>

<script>
import { Item, ItemPanel } from 'vue-flowchart-editor'
import { getPage } from '../../../api/omd/status'

export default {
  name: 'EditorItemPanel',
  components: { ItemPanel, Item },
  props: {
    // all nodes for drag to generate flowchart
    treeClick: {
      type: Function,
    },
  },
  data() {
    return {
      filterText: '',
      existList: [
        {
          id: 0,
          label: '生命周期模板列表',
          children: [
            {
              id: 1,
              label: '测试数据1',
              data: {
                nodes: [
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点1',
                    x: 358,
                    y: 262.66666412353516,
                    id: '5f2fae92',
                    index: 0,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点1',
                    x: 349,
                    y: 398.66666412353516,
                    id: '39784055',
                    index: 1,
                  },
                ],
                edges: [
                  {
                    source: '5f2fae92',
                    sourceAnchor: 2,
                    target: '39784055',
                    targetAnchor: 0,
                    id: '40ff05c5',
                    index: 2,
                  },
                ],
              },
            },
            {
              id: 2,
              label: '测试数据2',
              data: {
                nodes: [
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点1',
                    x: 319.5416564941406,
                    y: 396.66666412353516,
                    id: 'ee3b0618',
                    index: 0,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点2',
                    x: 192.54165649414062,
                    y: 277.66666412353516,
                    id: 'a96bfab6',
                    index: 4,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点3',
                    x: 360.5416564941406,
                    y: 152.66666412353516,
                    id: 'e76e769e',
                    index: 5,
                  },
                ],
                edges: [
                  {
                    source: 'e76e769e',
                    sourceAnchor: 2,
                    target: 'a96bfab6',
                    targetAnchor: 0,
                    id: '72117e49',
                    index: 1,
                  },
                  {
                    source: 'a96bfab6',
                    sourceAnchor: 2,
                    target: 'ee3b0618',
                    targetAnchor: 0,
                    id: '21db19e2',
                    index: 2,
                  },
                  {
                    source: 'e76e769e',
                    sourceAnchor: 1,
                    target: 'ee3b0618',
                    targetAnchor: 1,
                    id: '324dd9ae',
                    index: 3,
                  },
                ],
              },
            },
            {
              id: 3,
              label: '测试数据3',
              data: {
                nodes: [
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点1',
                    x: 130.54165649414062,
                    y: 108.66666412353516,
                    id: '9bc884ca',
                    index: 0,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点2',
                    x: 129.54165649414062,
                    y: 227.66666412353516,
                    id: 'd5997173',
                    index: 1,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点3',
                    x: 129.54165649414062,
                    y: 348.66666412353516,
                    id: '79e40c28',
                    index: 2,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点4',
                    x: 319.5416564941406,
                    y: 349.16666412353516,
                    id: '91a6982c',
                    index: 3,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点5',
                    x: 537.5416564941406,
                    y: 350.66666412353516,
                    id: '3939704b',
                    index: 4,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点6',
                    x: 533.5416564941406,
                    y: 230.66666412353516,
                    id: 'de373e3a',
                    index: 5,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点7',
                    x: 537.5416564941406,
                    y: 107.66666412353516,
                    id: '7bdf94ba',
                    index: 6,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点8',
                    x: 343.5416564941406,
                    y: 106.66666412353516,
                    id: '3e739b8e',
                    index: 7,
                  },
                ],
                edges: [
                  {
                    source: '9bc884ca',
                    sourceAnchor: 2,
                    target: 'd5997173',
                    targetAnchor: 0,
                    id: '88e19734',
                    index: 8,
                  },
                  {
                    source: 'd5997173',
                    sourceAnchor: 2,
                    target: '79e40c28',
                    targetAnchor: 0,
                    id: 'e38664d6',
                    index: 9,
                  },
                  {
                    source: '79e40c28',
                    sourceAnchor: 1,
                    target: '91a6982c',
                    targetAnchor: 3,
                    id: '3c95a9f2',
                    index: 10,
                  },
                  {
                    source: '91a6982c',
                    sourceAnchor: 1,
                    target: '3939704b',
                    targetAnchor: 3,
                    id: '5c517fcd',
                    index: 11,
                  },
                  {
                    source: '3939704b',
                    sourceAnchor: 0,
                    target: 'de373e3a',
                    targetAnchor: 2,
                    id: '037bce01',
                    index: 12,
                  },
                  {
                    source: 'de373e3a',
                    sourceAnchor: 0,
                    target: '7bdf94ba',
                    targetAnchor: 2,
                    id: 'b09bb221',
                    index: 13,
                  },
                  {
                    source: '7bdf94ba',
                    sourceAnchor: 3,
                    target: '3e739b8e',
                    targetAnchor: 1,
                    id: '466db0ea',
                    index: 14,
                  },
                  {
                    source: '3e739b8e',
                    sourceAnchor: 3,
                    target: '9bc884ca',
                    targetAnchor: 1,
                    id: '0ad68e07',
                    index: 15,
                  },
                ],
              },
            },
            {
              id: 4,
              label: '测试数据4',
              data: {
                nodes: [
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点6',
                    x: 387.5416564941406,
                    y: 310.66666412353516,
                    id: '61775a95',
                    index: 0,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点7',
                    x: 559.0416564941406,
                    y: 122.16666412353516,
                    id: '3ecf3a2c',
                    index: 4,
                  },
                  {
                    type: 'node',
                    size: '80*48',
                    shape: 'flow-rect',
                    color: '#1890FF',
                    label: '测试节点8',
                    x: 226.54165649414062,
                    y: 121.16666412353516,
                    id: '065c9aa9',
                    index: 5,
                  },
                ],
                edges: [
                  {
                    source: '065c9aa9',
                    sourceAnchor: 2,
                    target: '61775a95',
                    targetAnchor: 0,
                    id: 'd9ddab89',
                    index: 1,
                  },
                  {
                    source: '61775a95',
                    sourceAnchor: 0,
                    target: '3ecf3a2c',
                    targetAnchor: 2,
                    id: 'a010883c',
                    index: 2,
                  },
                  {
                    source: '3ecf3a2c',
                    sourceAnchor: 3,
                    target: '065c9aa9',
                    targetAnchor: 1,
                    id: '93207803',
                    index: 3,
                  },
                ],
              },
            },
            
          ],
        },
      ],
      nodeItems: [],
      loading: false
    }
  },
  created() {
      this.loading = true
    getPage(1, 99999).then(res => {
      this.loading = false
      if (res.data.code === 200) {
        this.nodeItems = res.data.data.records
      }
    })
  },
  computed: {
    filterNode() {
      return this.nodeItems.filter(item => item.id.includes(this.filterText))
    }
  },
}
</script>

<style lang="scss" scoped>
.item_panel_box {
  height: 100%;
  padding: 5px;
  overflow: hidden;
  .exist_list {
    max-height: 40%;
    overflow-y: scroll;
    .title {
      padding: 10px 0;
      text-align: center;
      font-size: 16px;
      font-weight: bold;
    }
  }
  .box_item {
    margin-top: 20px;
  }
}
.item-panel {
  width: 100%;
  height: 500px;
  text-align: center;
  overflow-y: scroll;
  .item {
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 12px;
    margin-left: auto;
    margin-right: auto;
    margin-bottom: 10px;
    user-select: none;

    &.item-flow-rect {
      padding: 6px;
      box-sizing: border-box;
      border: 1px solid rgb(24, 144, 255);
      background-color: rgba(24, 144, 255, 0.2);
    }

    &.item-flow-circle {
      width: 70px;
      height: 70px;
      border-radius: 60px;
      border: 1px solid rgb(250, 140, 22);
      background-color: rgba(250, 140, 22, 0.2);
    }

    &.item-flow-rhombus {
      width: 70px;
      height: 70px;
      margin: 25px auto;
      border: 1px solid rgb(19, 194, 194);
      background-color: rgba(19, 194, 194, 0.2);
      transform: rotate(45deg);

      span {
        transform: rotate(-45deg);
      }
    }

    &.item-img {
      max-width: 100px;
    }
  }
}
</style>
